==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/af-ZA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bevestig bates vir die verwydering van grootmaat',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Hersien die bates vir grootmaatverwydering hieronder. Sodra dit verwyder is, kan hierdie bates herstel word, maar hulle word nie meer geassosieer met enige gebruikers wat hulle tans toegewys is nie.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Jy is op die punt om te verwyder: bate_count bates.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Grootskaalse opdateringsbates',
    'bulk_update_help'	=> 'Met hierdie vorm kan u verskeie bates gelyktydig bywerk. Vul slegs die velde in wat u moet verander. Enige velde wat leeg is, bly onveranderd.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Gekontroleer na',
    'checkout_date'		=> 'Checkout Datum',
    'checkin_date'		=> 'Incheckdatum',
    'checkout_to'		=> 'Afrekenen na',
    'cost'				=> 'Aankoopskoste',
    'create'			=> 'Skep bate',
    'date'				=> 'Aankoop datum',
    'depreciation'	    => 'waardevermindering',
    'depreciates_on'	=> 'Depresiate On',
    'default_location'	=> 'Verstek Ligging',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL Datum',
    'eol_rate'			=> 'EOL-tarief',
    'expected_checkin'  => 'Verwagte tjekdatum',
    'expires'			=> 'verstryk',
    'fully_depreciated'	=> 'Ten volle gedepresieer',
    'help_checkout'		=> 'As u hierdie bate onmiddellik wil toewys, kies \'Klaar om te Implementeer\' uit die statuslys hierbo.',
    'mac_address'		=> 'MAC adres',
    'manufacturer'		=> 'vervaardiger',
    'model'				=> 'model',
    'months'			=> 'maande',
    'name'				=> 'Bate Naam',
    'notes'				=> 'notas',
    'order'				=> 'Bestellingnommer',
    'qr'				=> 'QR-kode',
    'requestable'		=> 'Gebruikers kan hierdie bate aanvra',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Kies Status Tipe',
    'serial'			=> 'Serial',
    'status'			=> 'status',
    'tag'				=> 'Bate-tag',
    'update'			=> 'Asset Update',
    'warranty'			=> 'waarborg',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'jaar',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/af-ZA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bevestig bates vir die verwydering van grootmaat',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Hersien die bates vir grootmaatverwydering hieronder. Sodra dit verwyder is, kan hierdie bates herstel word, maar hulle word nie meer geassosieer met enige gebruikers wat hulle tans toegewys is nie.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Jy is op die punt om te verwyder: bate_count bates.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Grootskaalse opdateringsbates',
    'bulk_update_help'	=> 'Met hierdie vorm kan u verskeie bates gelyktydig bywerk. Vul slegs die velde in wat u moet verander. Enige velde wat leeg is, bly onveranderd.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Gekontroleer na',
    'checkout_date'		=> 'Checkout Datum',
    'checkin_date'		=> 'Incheckdatum',
    'checkout_to'		=> 'Afrekenen na',
    'cost'				=> 'Aankoopskoste',
    'create'			=> 'Skep bate',
    'date'				=> 'Aankoop datum',
    'depreciation'	    => 'waardevermindering',
    'depreciates_on'	=> 'Depresiate On',
    'default_location'	=> 'Verstek Ligging',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL Datum',
    'eol_rate'			=> 'EOL-tarief',
    'expected_checkin'  => 'Verwagte tjekdatum',
    'expires'			=> 'verstryk',
    'fully_depreciated'	=> 'Ten volle gedepresieer',
    'help_checkout'		=> 'As u hierdie bate onmiddellik wil toewys, kies \'Klaar om te Implementeer\' uit die statuslys hierbo.',
    'mac_address'		=> 'MAC adres',
    'manufacturer'		=> 'vervaardiger',
    'model'				=> 'model',
    'months'			=> 'maande',
    'name'				=> 'Bate Naam',
    'notes'				=> 'notas',
    'order'				=> 'Bestellingnommer',
    'qr'				=> 'QR-kode',
    'requestable'		=> 'Gebruikers kan hierdie bate aanvra',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Kies Status Tipe',
    'serial'			=> 'Serial',
    'status'			=> 'status',
    'tag'				=> 'Bate-tag',
    'update'			=> 'Asset Update',
    'warranty'			=> 'waarborg',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'jaar',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
